Coverage for /home/chris/workspace/django-shop/shop/payment/urls: 75.00%

# Coverage for /home/chris/workspace/django-shop/shop/payment/urls : 75.00%

## 6 statements 5 run 1 missing 0 excluded 1 partial

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | #-*- coding: utf-8 -*- """ Loop over payment backends defined in settings.SHOP_PAYMENT_BACKENDS and add their URLs to the payment namespace. eg: http://www.example.com/shop/pay/paypal http://www.example.com/shop/pay/pay-on-delivery ... """ from django.conf.urls.defaults import patterns from shop.backends_pool import backends_pool urlpatterns = patterns('') # For every backend defined in the backend pool, load all the URLs it defines # in its get_urls() method. 19for backend in backends_pool.get_payment_backends_list(): urlpatterns = backend.get_urls() + urlpatterns